import { dataSource } from "../../data-source";
import { equipment } from "../../entity/configuration/equipment";
import DatabaseActionException from "../../exceptions/databaseActionException";

export default abstract class EquipmentService {
  /**
   * @description get all equipments
   * @returns {Promise<[Array<equipment>, number]>}
   */
  static async getAll({
    offset = 0,
    count = 25,
    search = "",
    noLimit = false,
    ids = [],
  }: {
    offset?: number;
    count?: number;
    search?: string;
    noLimit?: boolean;
    ids?: Array<string>;
  }): Promise<[Array<equipment>, number]> {
    let query = dataSource.getRepository(equipment).createQueryBuilder("equipment");

    if (search != "") {
      search.split(" ").forEach((term, index) => {
        const searchQuery = `%${term}%`;
        const dynamic = "searchQuery" + Math.random().toString(36).substring(2);
        if (index == 0) {
          query = query.where(`equipment.name LIKE :${dynamic}`, {
            [dynamic]: searchQuery,
          });
        } else {
          query = query.orWhere(`equipment.name LIKE :${dynamic}`, {
            [dynamic]: searchQuery,
          });
        }
      });
    }

    if (ids.length != 0) {
      query = query.where("equipment.id IN (:...ids)", { ids: ids });
    }

    if (!noLimit) {
      query = query.offset(offset).limit(count);
    }

    return await query
      .orderBy("equipment.name")
      .getManyAndCount()
      .then((res) => {
        return res;
      })
      .catch((err) => {
        throw new DatabaseActionException("SELECT", "equipment", err);
      });
  }

  /**
   * @description get equipment by id
   * @param {string} id
   * @returns {Promise<equipment>}
   */
  static async getById(id: string): Promise<equipment> {
    return dataSource
      .getRepository(equipment)
      .createQueryBuilder("equipment")
      .where("equipment.id = :id", { id: id })
      .getOneOrFail()
      .then((res) => {
        return res;
      })
      .catch((err) => {
        throw new DatabaseActionException("SELECT", "equipment", err);
      });
  }
}
