export type PermissionSection = "operation" | "configuration" | "management";

export type PermissionModule = "mission" | "force" | "vehicle" | "equipment" | "user" | "role" | "backup";

export type PermissionType = "read" | "create" | "update" | "delete";

export type PermissionString =
  | `${PermissionSection}.${PermissionModule}.${PermissionType}` // für spezifische Berechtigungen
  | `${PermissionSection}.${PermissionModule}.*` // für alle Berechtigungen in einem Modul
  | `${PermissionSection}.${PermissionType}` // für spezifische Berechtigungen in einem Abschnitt
  | `${PermissionSection}.*` // für alle Berechtigungen in einem Abschnitt
  | "*"; // für Admin

export type PermissionObject = {
  [section in PermissionSection]?: {
    [module in PermissionModule]?: Array<PermissionType> | "*";
  } & { all?: Array<PermissionType> | "*" };
} & {
  admin?: boolean;
};

export type SectionsAndModulesObject = {
  [section in PermissionSection]: Array<PermissionModule>;
};

export const permissionSections: Array<PermissionSection> = ["operation", "configuration", "management"];
export const permissionModules: Array<PermissionModule> = [
  "mission",
  "force",
  "vehicle",
  "equipment",
  "user",
  "role",
  "backup",
];
export const permissionTypes: Array<PermissionType> = ["read", "create", "update", "delete"];
export const sectionsAndModules: SectionsAndModulesObject = {
  operation: ["mission"],
  configuration: ["force", "vehicle", "equipment"],
  management: ["user", "role", "backup"],
};
